@@ -14,7 +14,7 @@ from tqdm import tqdm
 import os
 
 
-def predict_fasta(model, input_fasta, output, token_cores=8, datatype='int32', rc=False, replicates=1):
+def predict_fasta(model, input_fasta, output, token_cores=8, datatype='int32', rc=False, replicates=1, batch_size=512):
     """Predict pathogenic potentials from a fasta file."""
 
     alphabet = "ACGT"
@@ -34,19 +34,19 @@ def predict_fasta(model, input_fasta, output, token_cores=8, datatype='int32', r
             x_data = np.asarray(p.map(partial(tokenize, tokenizer=tokenizer, datatype=datatype,
                                               read_length=read_length), read_fasta(input_handle)))
     # Predict
-    y_pred, y_std = predict_array(model, x_data, output, rc, replicates)
+    y_pred, y_std = predict_array(model, x_data, output, rc, replicates, batch_size)
     end = time.time()
     print("Preprocessing & predictions for {} reads done in {} s".format(y_pred.shape[0], end - start))
     return y_pred, y_std
 
 
-def predict_npy(model, input_npy, output, rc=False, replicates=1):
+def predict_npy(model, input_npy, output, rc=False, replicates=1, batch_size=512):
     """Predict pathogenic potentials from a preprocessed numpy array."""
     x_data = np.load(input_npy, mmap_mode='r')
-    return predict_array(model, x_data, output, rc, replicates)
+    return predict_array(model, x_data, output, rc, replicates, batch_size)
 
 
-def predict_array(model, x_data, output, rc=False, replicates=1):
+def predict_array(model, x_data, output, rc=False, replicates=1, batch_size=512):
     """Predict pathogenic potentials from a preprocessed numpy array."""
     if rc:
         x_data = x_data[::, ::-1, ::-1]
@@ -56,12 +56,12 @@ def predict_array(model, x_data, output, rc=False, replicates=1):
     if replicates > 1:
         y_preds = []
         for i in tqdm(range(replicates)):
-            y_preds.append(np.ndarray.flatten(model.predict(x_data)))
+            y_preds.append(np.ndarray.flatten(model.predict(x_data, batch_size=batch_size)))
         y_preds = np.asarray(y_preds)
         y_pred = y_preds.mean(axis=0)
         y_std = y_preds.std(axis=0)
     else:
-        y_pred = np.ndarray.flatten(model.predict(x_data))
+        y_pred = np.ndarray.flatten(model.predict(x_data, batch_size=batch_size))
         y_std = None
 
     end = time.time()
